@@ -1,13 +1,10 @@
 //
 // conv.cc - Main Program for text converter program
 // Created: 19 Jan 1999
-// Author:  Theppitak Karoonboonyanan <thep@links.nectec.or.th>
+// Author:  Theppitak Karoonboonyanan <theppitak@gmail.com>
 //
 
-#include <stdio.h>
 #include "convfact.h"
-#include "utf8.h"
-#include "tis620.h"
 
 //
 // SYNOPSIS
