@@ -1,13 +1,12 @@
 //
 // convfact.h - Text Agent Factory
 // Created: 19 Jan 1999
-// Author:  Theppitak Karoonboonyanan <thep@links.nectec.or.th>
+// Author:  Theppitak Karoonboonyanan <theppitak@gmail.com>
 //
 
-#ifndef CONVFACT_INC
-#define CONVFACT_INC
+#ifndef __CONVFACT_H
+#define __CONVFACT_H
 
-#include <stdio.h>
 #include "convkit.h"
 
 enum ETextFormat {
@@ -18,5 +17,5 @@ enum ETextFormat {
 TextReader* CreateTextReader (ETextFormat format, const char* inText);
 TextWriter* CreateTextWriter (ETextFormat format, char* outText, int outLen);
 
-#endif // CONVFACT_INC
+#endif // __CONVFACT_H
 
