@@ -1,16 +1,18 @@
 //
 // convkit.h - Text Converter Kit
 // Created: 19 Jan 1999
-// Author:  Theppitak Karoonboonyanan <thep@links.nectec.or.th>
+// Author:  Theppitak Karoonboonyanan <theppitak@gmail.com>
 //
 
-#ifndef CONVKIT_INC
-#define CONVKIT_INC
+#ifndef __CONVKIT_H
+#define __CONVKIT_H
 
 #include "unichar.h"
 
 class TextReader {
 public:
+    virtual ~TextReader () {}
+
     virtual bool Read(unichar& c) = 0;
 
 public:
@@ -43,6 +45,8 @@ TextReader::curPos () const
 
 class TextWriter {
 public:
+    virtual ~TextWriter () {}
+
     virtual bool Write(unichar c) = 0;
 
 public:
@@ -75,5 +79,5 @@ TextWriter::spaceLeft () const
     return outLen;
 }
 
-#endif  // CONVKIT
+#endif  // __CONVKIT_H
 
