@@ -1,13 +1,12 @@
 //
 // tis620.h - TIS-620 Agents
 // Created: 19 Jan 1999
-// Author:  Theppitak Karoonboonyanan <thep@links.nectec.or.th>
+// Author:  Theppitak Karoonboonyanan <theppitak@gmail.com>
 //
 
-#ifndef TIS620_INC
-#define TIS620_INC
+#ifndef __TIS620_H
+#define __TIS620_H
 
-#include <stdio.h>
 #include "convkit.h"
 
 class TIS620Reader : public TextReader {
@@ -26,5 +25,5 @@ public:
     bool Write(unichar c);
 };
 
-#endif // TIS620_INC
+#endif // __TIS620_H
 
