@@ -1,15 +1,15 @@
 //
 // tischar.h - TIS-620 char set definitions
 // Created: 19 Jan 1999
-// Author:  Theppitak Karoonboonyanan <thep@links.nectec.or.th>
+// Author:  Theppitak Karoonboonyanan <theppitak@gmail.com>
 //
 
-#ifndef TISCHAR_INC
-#define TISCHAR_INC
+#ifndef __TISCHAR_H
+#define __TISCHAR_H
 
 typedef unsigned char tischar;
 
 const tischar BAD_TISCHAR = 0x80;
 
-#endif  // TISCHAR_INC
+#endif  // __TISCHAR_H
 
