@@ -1,13 +1,12 @@
 //
 // utf8.h - UTF-8 Agents
 // Created: 19 Jan 1999
-// Author:  Theppitak Karoonboonyanan <thep@links.nectec.or.th>
+// Author:  Theppitak Karoonboonyanan <theppitak@gmail.com>
 //
 
-#ifndef UTF8_INC
-#define UTF8_INC
+#ifndef __UTF8_H
+#define __UTF8_H
 
-#include <stdio.h>
 #include "convkit.h"
 
 class UTF8Reader : public TextReader {
@@ -28,5 +27,5 @@ public:
 
 int UTF8Bytes (unichar c);
 
-#endif  // UTF8_INC
+#endif  // __UTF8_H
 
