@@ -5,10 +5,6 @@
 #ifndef __FILEFILTER_H
 #define __FILEFILTER_H
 
-#if _MSC_VER >= 1000
-#pragma once
-#endif
-
 #include "filterx.h"
 
 class FileFilter
