@@ -5,10 +5,6 @@
 #ifndef __FILTERHTML_H
 #define __FILTERHTML_H
 
-#if _MSC_VER >= 1000
-#pragma once
-#endif
-
 #include "filterx.h"
 
 class FilterHtml : public FilterX
