@@ -5,10 +5,6 @@
 #ifndef __FILTERRTF_H
 #define __FILTERRTF_H
 
-#if _MSC_VER >= 1000
-#pragma once
-#endif
-
 #include "filterx.h"
 
 // Private implementation class
@@ -30,8 +26,7 @@ private:
     CS_CH_BYTE,
     CS_UNI,
     CS_UNI_COUNT,
-    CS_UNI_CODE,
-    CS_NONE
+    CS_UNI_CODE
   };
 
 private:
