@@ -5,15 +5,6 @@
 #include "maxwordseg.h"
 #include "wordstack.h"
 
-//////////////////////////////////////////////////////////////////////
-// Construction/Destruction
-//////////////////////////////////////////////////////////////////////
-
-MaxWordSeg::MaxWordSeg ()
-  : AbsWordSeg ()
-{
-}
-
 // Return number of ambiguous areas.
 int
 MaxWordSeg::CreateSentence ()
@@ -36,8 +27,8 @@ MaxWordSeg::CreateSentence ()
         }
       else
         {
-          stWord = i;
-          enAmb = LinkSep[IdxSep[stWord]];
+          stWord = i + 1;
+          enAmb = LinkSep[IdxSep[i]];
         }
     }
 
@@ -46,11 +37,9 @@ MaxWordSeg::CreateSentence ()
   while (enAmb <= textLen)
     {
       bool singleWord = true;
-      for (; stWord < enAmb && stWord < textLen; stWord++)
+      for (; stWord < enAmb; stWord++)
         {
-          if (IdxSep[stWord] < 0)
-            continue;
-          if (LinkSep[IdxSep[stWord]] > enAmb)
+          if (IdxSep[stWord] >= 0 && LinkSep[IdxSep[stWord]] > enAmb)
             {
               singleWord = false;
               enAmb = LinkSep[IdxSep[stWord]];
@@ -84,15 +73,12 @@ MaxWordSeg::CreateSentence ()
 int
 MaxWordSeg::saveSegment (int sepIdx, int idxSen, int lastPoint)
 {
-  int i;
+  const short int *srcSep = SepData[idxSen].Sep;
+  short int       *dstSep = SepData[2].Sep;
 
-  for (i = 0; SepData[idxSen].Sep[i] < lastPoint; i++)
+  while (*srcSep != -1 && *srcSep <= lastPoint)
     {
-      SepData[2].Sep[sepIdx++] = SepData[idxSen].Sep[i];
-    }
-  if (SepData[idxSen].Sep[i] == lastPoint)
-    {
-      SepData[2].Sep[sepIdx++] = SepData[idxSen].Sep[i];
+      dstSep[sepIdx++] = *srcSep++;
     }
 
   return sepIdx;
@@ -125,7 +111,7 @@ MaxWordSeg::WordSegArea (int stSeg, int enSeg)
         {
           if (LinkSep[IdxSep[Idx] + 1] != -1)
             {
-              BackTrackStack.Push (wordState (Idx, 0));
+              BackTrackStack.Push (WordState (Idx, 0));
             }
           SepData[senIdx].Sep[sepIdx++] = LinkSep[IdxSep[Idx]];
           score[++scoreidx] = ++SepData[senIdx].Score;
@@ -152,7 +138,7 @@ MaxWordSeg::WordSegArea (int stSeg, int enSeg)
   while (!BackTrackStack.Empty () && looptime++ <= 200)
     {
       bool stopCreate = false;
-      wordState wState = BackTrackStack.Top ();
+      WordState wState = BackTrackStack.Top ();
       BackTrackStack.Pop ();
 
       wState.branchState++;
@@ -168,35 +154,26 @@ MaxWordSeg::WordSegArea (int stSeg, int enSeg)
       SepData[senIdx].Score = (scoreidx < 0) ? 10000 : score[scoreidx];
 
       //loop for filling the rest sep point of new sentence
-      bool foundUnk;
       while (curState != enSeg)
         {
-          foundUnk = false;
+          SepData[senIdx].Sep[nextSepIdx++] = curState;
+          SepData[senIdx].Score++;
           if (IdxSep[curState] < 0)
-            {                   //found unknown string.
-              SepData[senIdx].Sep[nextSepIdx++] = curState;
-              SepData[senIdx].Score++;
-              score[++scoreidx] = SepData[senIdx].Score;
+            {
+              //unknown string, find its boundary and add penalty
               while (curState < enSeg && IdxSep[curState] < 0)
                 curState++;
-              foundUnk = true;
-              if (curState == enSeg)
-                break;
-            }
-          else if (LinkSep[IdxSep[curState] + 1] != -1)
-            {
-              //having another branch
-              //then it should push backtrack state into Stack.
-              BackTrackStack.Push (wordState (curState, 0));
-            }
-          SepData[senIdx].Sep[nextSepIdx++] = curState;
-          if (foundUnk)
-            {
               SepData[senIdx].Score += 5;
-              foundUnk = false;
             }
           else
-            SepData[senIdx].Score++;
+            {
+              if (LinkSep[IdxSep[curState] + 1] != -1)
+                {
+                  //another branch exists, push backtrack state
+                  BackTrackStack.Push (WordState (curState, 0));
+                }
+              curState = LinkSep[IdxSep[curState]];
+            }
           score[++scoreidx] = SepData[senIdx].Score;
           if (SepData[senIdx].Score >= bestScore - 1)
             {
@@ -204,13 +181,12 @@ MaxWordSeg::WordSegArea (int stSeg, int enSeg)
               stopCreate = true;
               break;
             }
-          curState = LinkSep[IdxSep[curState]];
-        }                       //finish create a new sentence.
+        }
       if (stopCreate)
         continue;
-      SepData[senIdx].Sep[nextSepIdx] = enSeg;
-      SepData[senIdx].Score += (foundUnk) ? 5 : 1;
-      SepData[senIdx].Sep[nextSepIdx + 1] = -1;
+      SepData[senIdx].Sep[nextSepIdx++] = enSeg;
+      SepData[senIdx].Score++;
+      SepData[senIdx].Sep[nextSepIdx] = -1;
       prevSenIdx = senIdx;
       if (SepData[senIdx].Score < bestScore)
         {
