@@ -18,8 +18,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <ctype.h>
-#include <time.h>
 #include <wchar.h>
 #include <wctype.h>
 
@@ -40,26 +38,9 @@ enum TextToken {
 
 static TextToken SplitToken (wchar_t** str, wchar_t* token);
 
-static AbsWordSeg*
-InitWordSegmentation (const char* dictpath, const char* method)
+static bool
+OpenDict (Dict* dict, const char* dictpath)
 {
-  AbsWordSeg* wseg = NULL;
-
-  if (method)
-    {
-      if (strcmp (method, "long") == 0)
-        wseg = new LongWordSeg;
-      else if (strcmp (method, "max") == 0)
-        wseg = new MaxWordSeg;
-    }
-
-  // fallback
-  if (!wseg)
-    wseg = new MaxWordSeg;
-
-  if (!wseg)
-    return NULL;
-
   // Dict search order:
   // 1. dictpath, if not NULL, exit on failure
   // 2. ${SWATHDICT} env, if not NULL, continue on failure
@@ -67,25 +48,38 @@ InitWordSegmentation (const char* dictpath, const char* method)
   // 4. WORDSEGDATADIR macro
   if (dictpath)
     {
-      if (wseg->InitDict (dictpath))
-        return wseg;
+      if (dict->open (dictpath))
+        return true;
     }
   else
     {
       dictpath = getenv ("SWATHDICT");
-      if (dictpath && wseg->InitDict (dictpath))
-        return wseg;
+      if (dictpath && dict->open (dictpath))
+        return true;
 
-      if (wseg->InitDict ("."))
-        return wseg;
+      if (dict->open ("."))
+        return true;
 
-      if (wseg->InitDict (WORDSEGDATA_DIR))
-        return wseg;
+      if (dict->open (WORDSEGDATA_DIR))
+        return true;
     }
 
-  // All fail
-  delete wseg;
-  return NULL;
+  return false;
+}
+
+static AbsWordSeg*
+InitWordSegmentation (const char* method)
+{
+  if (method)
+    {
+      if (strcmp (method, "long") == 0)
+        return new LongWordSeg;
+      else if (strcmp (method, "max") == 0)
+        return new MaxWordSeg;
+    }
+
+  // fallback
+  return new MaxWordSeg;
 }
 
 static void
@@ -95,11 +89,11 @@ ExitWordSegmentation (AbsWordSeg* wseg)
 }
 
 static void
-WordSegmentation (AbsWordSeg* wseg, const wchar_t* wbr, const wchar_t* line,
-                  wchar_t* output, int outputSz)
+WordSegmentation (AbsWordSeg* wseg, const Dict* dict, const wchar_t* wbr,
+                  const wchar_t* line, wchar_t* output, int outputSz)
 {
   short int *seps = new short int [outputSz];
-  int nSeps = wseg->WordSeg (line, seps, outputSz);
+  int nSeps = wseg->WordSeg (dict, line, seps, outputSz);
 
   const wchar_t* pLine = line;
   int wbrLen = wcslen (wbr);
@@ -160,12 +154,9 @@ Usage (int verbose)
                "\t\tlatex    : LaTeX file\n"
                "\t\tlambda   : The input and output are same as latex, except that\n"
                "\t\t           the word delimitor is ^^^^200b\n"
-//                "\t\twinlatex : LaTeX file shaping on Windows\n"
-//                "\t\tmaclatex : LaTeX file shaping on Macintosh\n"
                "\t-m   : choose word matching scheme when analyzing\n"
                "\t\tlong     : longest matching scheme\n"
                "\t\tmax      : maximal matching scheme\n"
-//                "\t-l   : line processing(effect only in a bigram algo.)\n"
                "\t-u   : specify encodings of input and output in 'i,o' form,\n"
                "\t       for input and output respectively, where 'i', 'o' is one of:\n"
                "\t\tu        : The input/output is in UTF-8\n"
@@ -177,20 +168,18 @@ Usage (int verbose)
 #ifndef WORDSEGDATA_DIR
 #define WORDSEGDATA_DIR "/usr/local/lib/wordseg"
 #endif
-//#define WORDSEGDATA_DIR "./data"
 
 int
 main (int argc, char* argv[])
 {
-  char mode = 1;                // 0 = display, 1 = don't display message
   const char* wbr = NULL;
   const char* dictpath = NULL;
   const char* method = NULL;
   const char* fileformat = NULL;
   const char* unicode = NULL;
+  bool verbose = false;
   bool muleMode;
   bool thaiFlag;
-  bool wholeLine = false;
 
   muleMode = false;
   for (int iargc = 1; iargc < argc; iargc++)
@@ -198,7 +187,7 @@ main (int argc, char* argv[])
       if (strcmp ("mule", argv[iargc]) == 0)
         {
           muleMode = true;
-          mode = 1;
+          verbose = false;
         }
       else if (strcmp ("-b", argv[iargc]) == 0 && iargc + 1 < argc)
         {
@@ -215,17 +204,12 @@ main (int argc, char* argv[])
       else if (strcmp ("-v", argv[iargc]) == 0 ||
                strcmp ("--verbose", argv[iargc]) == 0)
         {
-          mode = 0;
+          verbose = true;
         }
       else if (strcmp ("-m", argv[iargc]) == 0 && iargc + 1 < argc)
         {
           method = argv[++iargc];
         }
-      else if (strcmp ("-l", argv[iargc]) == 0)
-        {
-          //send only token which has no white space in to wordseg
-          wholeLine = true;
-        }
       else if (strcmp ("-u", argv[iargc]) == 0 && iargc + 1 < argc)
         {
           unicode = argv[++iargc];
@@ -249,10 +233,14 @@ main (int argc, char* argv[])
         }
     }
 
-  if (mode == 0)
+  if (verbose)
     printf ("*** Word Segmentation ***\n");
 
-  AbsWordSeg* wseg = InitWordSegmentation (dictpath, method);
+  Dict dict;
+  if (!OpenDict (&dict, dictpath))
+    return 1;
+
+  AbsWordSeg* wseg = InitWordSegmentation (method);
   if (!wseg)
     return 1;
 
@@ -291,7 +279,7 @@ main (int argc, char* argv[])
               FltX->Print (wLine, thaiFlag);
               continue;
             }
-          WordSegmentation (wseg, FltX->GetWordBreak(), wLine,
+          WordSegmentation (wseg, &dict, FltX->GetWordBreak(), wLine,
                             wsegOut, N_ELM (wsegOut));
           FltX->Print (wsegOut, thaiFlag);
         }
@@ -307,7 +295,7 @@ main (int argc, char* argv[])
         }
       while (!feof (stdin))
         {
-          if (mode == 0)
+          if (verbose)
             printf ("Input : ");
 
           if (!ConvGetS (wLine, N_ELM (wLine), stdin, isUniIn))
@@ -316,7 +304,7 @@ main (int argc, char* argv[])
           if (L'\n' == wLine [len - 1])
             wLine [--len] = 0;
 
-          if (mode == 0)
+          if (verbose)
             printf ("Output: ");
 
           if (0 == wLine[0])
@@ -325,38 +313,26 @@ main (int argc, char* argv[])
               continue;
             }
 
-          if (!wholeLine)
-            {
-              int tokenFlag;
-              wchar_t* startStr = wLine;
-              wchar_t wToken[MAXLEN];
+          int tokenFlag;
+          wchar_t* startStr = wLine;
+          wchar_t wToken[MAXLEN];
 
-              while ((tokenFlag = SplitToken (&startStr, wToken)) != TTOK_EOT)
+          while ((tokenFlag = SplitToken (&startStr, wToken)) != TTOK_EOT)
+            {
+              switch (tokenFlag)
                 {
-                  switch (tokenFlag)
-                    {
-                      case TTOK_THAI:
-                        WordSegmentation (wseg, wcwbr, wToken, wsegOut,
-                                          N_ELM (wsegOut));
-                        ConvPrint (stdout, wsegOut, isUniOut);
-                        break;
+                  case TTOK_THAI:
+                    WordSegmentation (wseg, &dict, wcwbr, wToken, wsegOut,
+                                      N_ELM (wsegOut));
+                    ConvPrint (stdout, wsegOut, isUniOut);
+                    break;
 
-                      case TTOK_WSPACE:
-                      case TTOK_ETC:
-                      default:
-                        ConvPrint (stdout, wToken, isUniOut);
-                        break;
-                    }
-                  if (muleMode)
-                    {
-                      ConvPrint (stdout, wcwbr, isUniOut);
-                    }
+                  case TTOK_WSPACE:
+                  case TTOK_ETC:
+                  default:
+                    ConvPrint (stdout, wToken, isUniOut);
+                    break;
                 }
-            }
-          else
-            {
-              WordSegmentation (wseg, wcwbr, wLine, wsegOut, N_ELM (wsegOut));
-              ConvPrint (stdout, wsegOut, isUniOut);
               if (muleMode)
                 {
                   ConvPrint (stdout, wcwbr, isUniOut);
